\version "2.18.0"

% このソースファイルは、スコアに対応するMIDIデータを出力するためのもの。
% LilyPondのレンダリング時間の大半は音符の紙面配置の調節に要するものであり、欲しいのがMIDIだけであれば、別途出力させた方が早い。
% また、スコア用のstaffデータをそのままMIDIに移すと、移調楽器の音がトランスポーズされた状態で出力されてしまい、そのままでは聞けなくなる。
% 以上の観点から、MIDIデータは別口で吐き出した方が良い。


% ちなみに、生成されるMIDIの分解能は384になる。これは必ずしも標準的な値ではないので、異なるソフトでMIDIデータを再利用する場合、移動先であらためて変更する必要があるかも。


% 次の1行は、生成されるPDF内のリンク作成を抑制する。
% ONにしていると配布するPDFにパソコン内のパスが残ってしまい、セキュリティ上問題がある。
\pointAndClickOff




% 各楽器の実体は以下のファイルに別途格納。トランペットの1~3番など1ファイルにまとめても良いが、曲が長いと切れ目が見えなくて不便なのであえて分けるんだゾ
\include "1_1_piccolo.ly"
\include "1_2_flute1.ly"
\include "1_3_flute2.ly"
\include "1_4_oboe.ly"
\include "1_5_bassoon.ly"

\include "2_1_clarinetEs.ly"
\include "2_2_clarinet1.ly"
\include "2_3_clarinet2.ly"
\include "2_4_clarinet3.ly"
\include "2_5_clarinetAlto.ly"
\include "2_6_clarinetBass.ly"

\include "3_1_saxAlto1.ly"
\include "3_2_saxAlto2.ly"
\include "3_3_saxTenor.ly"
\include "3_4_saxBaritone.ly"

\include "4_1_trumpet1.ly"
\include "4_2_trumpet2.ly"
\include "4_3_trumpet3.ly"

\include "5_1_horn1and2.ly"
\include "5_2_horn3.ly"   %小編成用。ホルン4番を含む場合は1and2から設定をぶっこ抜いて来る

\include "6_1_trombone1.ly"
\include "6_2_trombone2.ly"
\include "6_3_trombone3.ly"

\include "7_1_euphonium.ly"
\include "7_2_tuba.ly"
\include "7_3_stringbass.ly"

\include "8_1_timpani.ly"
\include "8_2_percussion1.ly"
\include "8_3_percussion2.ly"
\include "8_4_percussion3.ly"
\include "8_5_percussion4.ly"


% 楽曲のヘッダ（メタデータ）は以下のファイルで一括指定する
\include "0_1_metadata.ly"

% 楽曲のマーカー（練習番号および全パートにかかわる強弱・テンポ指定など）は以下のファイルで一括指定する
\include "0_2_marker.ly"




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  MIDIデータに関わる設定項目
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



% 奏法スクリプトをインクルードする。MIDIデータにアーティキュレーションを反映させたい場合に使う

\include "articulate.ly"


% MIDIデータの拡張子を変更したい場合に使う

#(ly:set-option 'midi-extension "mid")



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  譜の全体に関わる設定項目
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% まあMIDI吐き出すだけなら関係ない設定項目だけど

\paper {
  #(set-paper-size "a3")
}

#(set-global-staff-size 14)


% 全パート譜に関してレイアウトを一括変更したいならば、以下でエングラーバを操作する。ここもMIDI吐き出すだけなら関係ない
\layout {
}




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%   曲が長くてレンダリングに時間がかかる場合は、以下で出力範囲を定義
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
  
%  showFirstLength = R2.*8 % 最初の8小節だけを出力
%  showLastLength = R2.*32 % 最後の32小節だけを出力

  % さらに細かく出力範囲を制御したい場合は、マーカーに \set Score.skipTypesetting = ##t を指定するとよい
  % 詳細は 「3.4.2 校正済みの音楽をスキップする」
  % MIDI出すだけならそこまで時間は掛からない（レンダリング時間の大半は音符の紙面上での衝突回避処理に費やされる）ので、ひとまず無視しておk


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  ここからbookを定義
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% scoreをbookで囲む。このセクションにより、includeされたファイル中のscoreセクションからの出力を抑制し、総譜だけを明示的に出力できる


\book {

  \bookOutputName "MIDI"  % 出力されるスコアのpdfファイルの名前をここで指定


  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  %  ここからスコアを定義
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

  \score {

   \unfoldRepeats \articulate % スコアブロック内の各セクションを \articulateで囲むと、奏法スクリプトが使用される
   <<

   <<

 % なおshortInstrumentNameは楽器名の略記（2段目以降に表示）。
 % 各楽器ファイル内で定義すると、パート譜の2段目以降の全段にも律儀に記載されてしまうので、ここで初めて定義

 % grobalMarker は全てのパートに入れないと、転調が反映されない



  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  %  ここから木管楽器
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


  \new StaffGroup ="SectWoodwind"  <<

    \new Staff = "Piccolo" \with { 
      shortInstrumentName = \markup { \italic "*Picc. " } 
    }
    <<
      \piccolo %音符の中身を保持しているオブジェクト
      \grobalMarker                %これを入れないと転調が反映されない
    >>
      
    \new Staff = "FluteFirst" \with { 
      shortInstrumentName = \markup { "Fl. 1 " } 
    }
    <<
      \flutefirst %音符の中身を保持しているオブジェクト
      \grobalMarker                %これを入れないと転調が反映されない
    >>

    \new Staff = "FluteSecond" \with { 
      shortInstrumentName = \markup { "Fl. 2 " } 
    }
    <<
      \flutesecond %音符の中身を保持しているオブジェクト
      \grobalMarker                %これを入れないと転調が反映されない
    >>

    \new Staff = "Oboe" \with { 
      shortInstrumentName = \markup { \italic "*Ob. " } 
    }
    <<
      \oboe %音符の中身を保持しているオブジェクト
      \grobalMarker                %これを入れないと転調が反映されない
    >>

    \new Staff = "Bassoon" \with { 
      shortInstrumentName = \markup { \italic "*Bsn. " } 
    }
    <<
      \bassoon %音符の中身を保持しているオブジェクト
      \grobalMarker                %これを入れないと転調が反映されない
    >>

  >>

% クラリネットセクションの皆さんを定義

  \new StaffGroup ="SectClarinet" <<

    \new Staff = "ClarinetEs" \with { 
      shortInstrumentName = \markup { \italic {"*E" \smaller \flat " Cl. "} } 
    }
    <<
      \clarinetes %音符の中身を保持しているオブジェクト
      \grobalMarker %グローバルマーカー
    >>

    \new Staff = "ClarinetFirst" \with { 
      shortInstrumentName = \markup { "Cl. 1 " } 
    }
    <<
      \clarinetfirst %音符の中身を保持しているオブジェクト
      \grobalMarker %グローバルマーカー
    >>

    \new Staff = "ClarinetSecond" \with { 
      shortInstrumentName = \markup { "Cl. 2 " } 
    }
    <<
      \clarinetsecond %音符の中身を保持しているオブジェクト
      \grobalMarker %グローバルマーカー
    >>

    \new Staff = "ClarinetThird" \with { 
      shortInstrumentName = \markup { "Cl. 3 " } 
    }
    <<
      \clarinetthird %音符の中身を保持しているオブジェクト
      \grobalMarker %グローバルマーカー
    >>

    \new Staff = "ClarinetAlto" \with { 
      shortInstrumentName = \markup { \italic {"*A. Cl. "} } 
    }
    <<
      \clarinetalto %音符の中身を保持しているオブジェクト
      \grobalMarker %グローバルマーカー
    >>

    \new Staff = "ClarinetBass" \with { 
      shortInstrumentName = \markup { "B. Cl. " } 
    }
    <<
      \clarinetbass %音符の中身を保持しているオブジェクト
      \grobalMarker %グローバルマーカー
    >>

  >>


% サックスセクションの皆さんを定義

  \new StaffGroup ="SectSax" <<

    \new Staff = "SaxAltoFirst" \with { 
      shortInstrumentName = \markup { "A. Sax. 1 " } 
    }
    <<
      \saxaltofirst %音符の中身を保持しているオブジェクト
      \grobalMarker %グローバルマーカー
    >>

    \new Staff = "SaxAltoSecond" \with { 
      shortInstrumentName = \markup { "A. Sax. 2 " } 
    }
    <<
      \saxaltosecond %音符の中身を保持しているオブジェクト
      \grobalMarker %グローバルマーカー
    >>

    \new Staff = "SaxTenor" \with { 
      shortInstrumentName = \markup { "T. Sax. " } 
    }
    <<
      \saxtenor %音符の中身を保持しているオブジェクト
      \grobalMarker %グローバルマーカー
    >>

    \new Staff = "SaxBaritone" \with { 
      shortInstrumentName = \markup { "Bar. Sax. " } 
    }
    <<
      \saxbaritone %音符の中身を保持しているオブジェクト
      \grobalMarker %グローバルマーカー
    >>

  >>

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  %  ここから金管楽器
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% トランペットの皆さんを定義

  \new StaffGroup ="SectTrumpet" <<

    \new Staff = "TrumpetFirst" \with { 
      shortInstrumentName = \markup { "Trp. 1 " } 
      % 以下の3つのエングラーバは、練習番号をこの譜表に記載する（通常は最上段の譜表にしか表示できない）
      \consists "Mark_engraver"
      \consists "Staff_collecting_engraver"
      \consists "Metronome_mark_engraver"
    }
    <<
      \trumpetfirst %音符の中身を保持しているオブジェクト
      \grobalMarker %グローバルマーカー
    >>

    \new Staff = "TrumpetSecond" \with { 
      shortInstrumentName = \markup { "Trp. 2 " } 
    }
    <<
      \trumpetsecond %音符の中身を保持しているオブジェクト
      \grobalMarker %グローバルマーカー
    >>

    \new Staff = "TrumpetThird" \with { 
      shortInstrumentName = \markup { "Trp. 3 " } 
    }
    <<
      \trumpetthird %音符の中身を保持しているオブジェクト
      \grobalMarker %グローバルマーカー
    >>

  >>


  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  %  ホルンセクション
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  

% ホルンの皆さんを定義

  \new StaffGroup ="SectHorn" <<

    \new Staff = "HornFirstSecond" \with { 
      shortInstrumentName = \markup { "Hrns. 1, 2 " } 
    }
    <<
      \hornfirstsecond %音符の中身を保持しているオブジェクト
      \grobalMarker %グローバルマーカー
    >>

    \new Staff = "HornThird" \with { 
      shortInstrumentName = \markup { "Hrn. 3 " } 
    }
    <<
      \hornthird %音符の中身を保持しているオブジェクト
      \grobalMarker %グローバルマーカー
    >>

% 大編成の場合は Hrns. 3, 4 が以下のようになる
%{
    \new Staff = "HornThirdFourth" \with { 
      shortInstrumentName = \markup { "Hrns. 3, 4 " } 
    }
    <<
      \hornthirdfourth %音符の中身を保持しているオブジェクト
      \grobalMarker %グローバルマーカー
    >>
%}

  >>


% トロンボーンの皆さんを定義
  \new StaffGroup ="SectTrombone" <<

    \new Staff = "TromboneFirst" \with { 
      shortInstrumentName = \markup { "Trb. 1 " } 
    }
    <<
      \trombonefirst %音符の中身を保持しているオブジェクト
      \grobalMarker %グローバルマーカー
    >>

    \new Staff = "TromboneSecond" \with { 
      shortInstrumentName = \markup { "Trb. 2 " } 
    }
    <<
      \trombonesecond %音符の中身を保持しているオブジェクト
      \grobalMarker %グローバルマーカー
    >>

    \new Staff = "TromboneThird" \with { 
      shortInstrumentName = \markup { "Trb. 3 " } 
    }
    <<
      \trombonethird %音符の中身を保持しているオブジェクト
      \grobalMarker %グローバルマーカー
    >>

  >>


% 低音セクションの皆さんを定義
  \new StaffGroup ="SectBass" <<

    \new Staff = "Euphonium" \with { 
      shortInstrumentName = \markup { "Euph. " } 
    }
    <<
      \euphonium %音符の中身を保持しているオブジェクト
      \grobalMarker %グローバルマーカー
    >>

    \new Staff = "Tuba" \with { 
      shortInstrumentName = \markup { "Tub. " } 
    }
    <<
      \tuba %音符の中身を保持しているオブジェクト
      \grobalMarker %グローバルマーカー
    >>

    \new Staff = "StringBass" \with { 
      shortInstrumentName = \markup { \italic "*St. B. " } 
    }
    <<
      \stringbass %音符の中身を保持しているオブジェクト
      \grobalMarker %グローバルマーカー
    >>

  >> % ここまで低音セクション




  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  %  ここから打楽器
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



% 打楽器セクションの皆さんを定義
  \new StaffGroup ="SectPercussion" \with {
  }
  <<

% ちなみに打楽器の入力方法として、少なくとも以下の2つがある
% 方法1 MIDIノートの音高で打ち込み、これを RhythmicStaff に食べさせて音高情報を消す
% 方法2 \drummode を用いて打楽器の名前でノートを打ち込み、これを DrumStaff を用いてスコアに入れる
% MIDIデータが既にあるなら、方法1が楽だろう。しかし、奏法に応じた符頭や譜表の線の設定といった自由度は低い
% 以下では、シンバル等については原則、方法2を用いる


% ティンパニ
    \new Staff = "Timpani" \with { 
      shortInstrumentName = \markup { "Timp. " } 
      % 以下の3つのエングラーバは、練習番号をこの譜表に記載する（通常は最上段の譜表にしか表示できない）
      \consists "Mark_engraver"
      \consists "Staff_collecting_engraver"
      \consists "Metronome_mark_engraver"
    }
    <<
      \timpani %音符の中身を保持しているオブジェクト
      \grobalMarker %グローバルマーカー
    >>



% 打楽器1 グロッケン
    \new Staff = "PercussionFirst" \with { 
      shortInstrumentName = \markup { "Perc. 1 " } 
    }
    <<
      \percussionfirst %音符の中身を保持しているオブジェクト
      \grobalMarker %グローバルマーカー
    >>


% スネア、バスドラム、シンバルは通常のスタッフではなく、DrumStaff を使用する。

% なお、何も考えずに書き出したMIDIデータの場合、
% bda   は B1
% sn    は D2
% symc  は C#3
% trio  は A5
% trim  は G#5
% で、それぞれチャンネルは10


% 打楽器2 スネアドラム
    \new DrumStaff = "PercussionSecond" \with { 
      drumStyleTable = #percussion-style %全ての打楽器を1つの線上に
      \override StaffSymbol #'line-count = #1  % 五線の代わりに1本の線で

      midiInstrument = #"orchestra kit"
      shortInstrumentName = \markup { "Perc. 2 " } 
    }
    <<
      \percussionsecond  %音符の中身を保持しているオブジェクト
      \grobalMarker                %これを入れないと転調が反映されない
    >>


% 打楽器3 バスドラム
    \new DrumStaff = "PercussionThird" \with { 
      drumStyleTable = #percussion-style %全ての打楽器を1つの線上に
      \override StaffSymbol #'line-count = #1  % 五線の代わりに1本の線で

      midiInstrument = #"orchestra kit"
      shortInstrumentName = \markup { "Perc. 3 " } 
    }
    <<
      \percussionthird  %音符の中身を保持しているオブジェクト
      \grobalMarker                %これを入れないと転調が反映されない
    >>



% 打楽器4 シンバル
    \new DrumStaff = "PercussionFour" \with { 
      drumStyleTable = #percussion-style %全ての打楽器を1つの線上に
      \override StaffSymbol #'line-count = #1  % 五線の代わりに1本の線で

      midiInstrument = #"orchestra kit"
      shortInstrumentName = \markup { "Perc. 4 " } 
    }
    <<
      \percussionfourth  %音符の中身を保持しているオブジェクト
      \grobalMarker                %これを入れないと転調が反映されない
    >>

  >> % ここまで打楽器セクション


  >>  % ここまでが譜表の定義



  >> % ここまでが \articulate の影響を受ける


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  ここから MIDI ブロック
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

  % このソースファイルは \score ブロック内に \midi を持ち、 \layout は持たない
  % 従って、MIDIファイルを生成するがPDFは出力しない。

  % MIDIデータいらないならば以下の\midiブロックをコメントアウト

  % MIDIチャンネルは1-16までStaff毎に（上から順に）割り当てられ、16を超えるとまた1から順に再利用されます。
  % なので、Flute First はch=2なのに Flute Second は ch=3 といった風に、後々使いにくいかもしれまえん。

  % DrumStaffにかんしてはchannnel 10が割り当てられる。
  % ただし、Note lengthが本来の音価のまま出力されるので、MIDIシーケンサで読むと違和感あるかも

  \midi {
    \tempo 4 = 96  % テンポは曲によって異なるので適宜調整してくだしあ  
    \context {
      \Score
%      midiChannelMapping = #'instrument'  % このオプションはMIDIチャンネルのマッピングを楽器毎に変更できる筈なのだが、なぜか上手く作動しない
    }
  }   




%ここまでがscoreセクション
}

%ここまでがbookセクション
}




